@@ -145,7 +145,7 @@ class AdhocServiceResultsMixin:
             ):
                 return adhocservice
         raise DALServiceError(
-            "No Adhoc Service with ivo-id {}!".format(ivo_id))
+            f"No Adhoc Service with ivo-id {ivo_id}!")
 
     def get_adhocservice_by_id(self, id_):
         """
@@ -165,7 +165,7 @@ class AdhocServiceResultsMixin:
             if adhocservice.ID == id_:
                 return adhocservice
         raise DALServiceError(
-            "No Adhoc Service with service_def id {}!".format(id_))
+            f"No Adhoc Service with service_def id {id_}!")
 
 
 class DatalinkResultsMixin(AdhocServiceResultsMixin):
@@ -510,7 +510,7 @@ class DatalinkService(DALService, AvailabilityMixin, CapabilityMixin):
             the output format
         """
         return DatalinkQuery(
-            self.baseurl, id=id, responseformat=responseformat, **keywords)
+            self.baseurl, id=id, responseformat=responseformat, session=self._session, **keywords)
 
 
 class DatalinkQuery(DALQuery):
@@ -768,7 +768,7 @@ class DatalinkResults(DatalinkResultsMixin, DALResults):
                     additional_terms.extend(voc["terms"][term]["narrower"])
             core_terms = core_terms + additional_terms
 
-        semantics = set("#" + term for term in core_terms) | set(other_terms)
+        semantics = {"#" + term for term in core_terms} | set(other_terms)
         for record in self:
             if record.semantics in semantics:
                 yield record
